@@ -102,16 +102,16 @@ class Graph(BaseGraph):
                 self.margin.left, self.margin.top))
         self.nodes['tooltip'] = self.svg.node(
             self.nodes['tooltip_overlay'],
-            id="tooltip",
             transform='translate(0 0)',
-            style="opacity: 0")
+            style="opacity: 0",
+            **{'class': 'tooltip'})
 
         a = self.svg.node(self.nodes['tooltip'], 'a')
         self.svg.node(a, 'rect',
-                      id="tooltip-box",
                       rx=self.tooltip_border_radius,
                       ry=self.tooltip_border_radius,
-                      width=0, height=0)
+                      width=0, height=0,
+                      **{'class': 'tooltip-box'})
         text = self.svg.node(a, 'text', class_='text')
         self.svg.node(text, 'tspan', class_='label')
         self.svg.node(text, 'tspan', class_='value')
@@ -495,10 +495,9 @@ class Graph(BaseGraph):
             self._y_2nd_labels = [(self._format(ymin + i * scale), pos)
                                   for i, pos in enumerate(y_pos)]
 
-            min_2nd = float(self._y_2nd_labels[0][0])
             self._scale = left_range / right_range
             self._scale_diff = y_pos[0]
-            self._scale_min_2nd = min_2nd
+            self._scale_min_2nd = ymin
 
     def _post_compute(self):
         pass
